Module: Booth::Concerns::Action

Overview

An “Action” is something that is called from a Rails controller. It contains all the logic that the controller action is supposed to execute. By convention the “authentication scope” and the “request object” are passed in.