Class: Booth::Core::Sessions::HistoricalLocations
- Inherits:
-
Object
- Object
- Booth::Core::Sessions::HistoricalLocations
- Includes:
- Calls
- Defined in:
- lib/booth/core/sessions/historical_locations.rb
Instance Method Summary collapse
-
#call ⇒ Object
TODO: Show IPs for cities that are different from the most recent IP.
Instance Method Details
#call ⇒ Object
TODO: Show IPs for cities that are different from the most recent IP.
12 13 14 15 16 |
# File 'lib/booth/core/sessions/historical_locations.rb', line 12 def call return if historical_locations.values.blank? historical_locations.values.reject { it == location }.uniq.sort.join(', ').presence end |