Exception: Booth::Errors::MustBeJson

Inherits:
BadRequest show all
Defined in:
lib/booth/errors.rb

Instance Method Summary collapse

Constructor Details

#initialize(message = 'This feature is only reachable in the format JSON') ⇒ MustBeJson

Returns a new instance of MustBeJson.



59
60
61
# File 'lib/booth/errors.rb', line 59

def initialize(message = 'This feature is only reachable in the format JSON')
  super
end