Class: Booth::Testing::Support::VirtualAuthenticators::Load

Inherits:
Object
  • Object
show all
Includes:
Logging, Calls, Capybara::DSL
Defined in:
lib/booth/testing/support/virtual_authenticators/load.rb

Instance Method Summary collapse

Instance Method Details

#callObject

Raises:

  • (NotImplementedError)


14
15
16
17
18
19
20
21
# File 'lib/booth/testing/support/virtual_authenticators/load.rb', line 14

def call
  raise NotImplementedError, 'Load needs to be reimplemented for Playwright using CDP'
  # Previously this loaded credentials from a Selenium virtual authenticator object
  # and added them to a new authenticator. With CDP, we'd need to:
  # 1. Get credentials from the source authenticator via WebAuthn.getCredentials
  # 2. Create a new authenticator
  # 3. Add the credentials via WebAuthn.addCredential
end