Class: Booth::Userland::Sessions::Show
- Inherits:
-
Object
- Object
- Booth::Userland::Sessions::Show
- Includes:
- Concerns::Action
- Defined in:
- lib/booth/userland/sessions/show.rb
Overview
‘DELETE /sessions/123` may present a page with a WebAuth authentication challenge. That challenge is responded to asynchronously and in that response the server destroys the session. After that, the page is reloaded by JS using `GET /sessions/123`, which is the `show` action. But we don’t actually have a show action for sessions. We just redirect to the index action with an informative flash message that the session was now deleted.
Instance Method Summary collapse
Instance Method Details
#call ⇒ Object
14 15 16 17 18 19 20 |
# File 'lib/booth/userland/sessions/show.rb', line 14 def call request.must_be_get! request.must_be_html! request.must_be_logged_in! ::Booth::Userland::Sessions::Transitions::Show::EnterWebauth.call request:, scope: end |