Module: Booth::Concerns::Action
- Extended by:
- ActiveSupport::Concern
- Included in:
- Userland::Logins::Create, Userland::Logins::Destroy, Userland::Logins::New, Userland::Onboardings::Show, Userland::Onboardings::Update, Userland::Registrations::Create, Userland::Registrations::New, Userland::Remotes::Show, Userland::Remotes::Update, Userland::Sessions::DestroyOneOrOther, Userland::Sessions::Index, Userland::Sessions::Show, Userland::Webauths::Create, Userland::Webauths::Destroy, Userland::Webauths::Index, Userland::Webauths::New, Userland::Webauths::Sudo
- Defined in:
- lib/booth/concerns/action.rb
Overview
An “Action” is something that is called from a Rails controller. It contains all the logic that the controller action is supposed to execute. By convention the “authentication scope” and the “request object” are passed in.