Class: Booth::Core::Sessions::ToPassport

Inherits:
Object
  • Object
show all
Includes:
Logging, Calls
Defined in:
lib/booth/core/sessions/to_passport.rb

Overview

A Passport is an immutable representation of your current browser-session. For convenience, we add information about the Credential belonging to that session.

Instance Method Summary collapse

Instance Method Details

#callObject



14
15
16
17
# File 'lib/booth/core/sessions/to_passport.rb', line 14

def call
  # ::Booth::ToStruct.call(attributes)
  ::Booth::Passport.new(**attributes)
end