Exception: Booth::Errors::MustBeJson
- Inherits:
-
BadRequest
- Object
- StandardError
- Error
- BadRequest
- Booth::Errors::MustBeJson
- Defined in:
- lib/booth/errors.rb
Instance Method Summary collapse
-
#initialize(message = 'This feature is only reachable in the format JSON') ⇒ MustBeJson
constructor
A new instance of MustBeJson.
Constructor Details
#initialize(message = 'This feature is only reachable in the format JSON') ⇒ MustBeJson
Returns a new instance of MustBeJson.
59 60 61 |
# File 'lib/booth/errors.rb', line 59 def initialize( = 'This feature is only reachable in the format JSON') super end |